package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`)I`!````(!P`(`$```!``````````&@#`0``
M`````````$``.``)`$``&P`:``8````$````0`````````!````@`0```$``
M`"`!````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"`"`!````.`(`(`$````3`````````!,``````````0`````````!````
M!0``````````````````(`$````````@`0```-"F````````T*8`````````
M``$```````$````&````X/T```````#@_0$@`0```.#]`2`!````<`0`````
M``"8!````````````0```````@````8```#P_0```````/#]`2`!````\/T!
M(`$````0`@```````!`"````````"``````````$````!````$P"````````
M3`(`(`$```!,`@`@`0```$0`````````1``````````$`````````%#E=&0$
M````%*$````````4H0`@`0```!2A`"`!````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````.#]````````X/T!(`$```#@_0$@
M`0```"`"````````(`(````````!`````````"]L:6(O;&0M;&EN=7@N<V\N
M,@``!````!0````#````1TY5`!%_;-1#"OC+>73LI2?)CT2/1T?,!````!``
M```!````1TY5```````#`````@`````````K````0P````0````(````(!`0
M``5`!(1H`@`$@(8"A(*)``()(`0(B(`00;H``@A#``````````````!$````
M``````````!%`````````$8```!'`````````$@`````````2@``````````
M````2P```$P`````````30```$X```!0`````````%$```!2````4P``````
M````````````````````````5````%4```!6````5P```%@```!:````````
M`%L`````````7```````````````B0=PTVL:GE"CX/M)F4_#F^-'Q@%FK\QF
M0T75[+OCDGRS`8MO;\7?'Q6,)<PNQ9NV:PE#UB'_Y`[[H6Q@P^4_+`TZEPO/
MWD<MV7%8''^IG)OAIP(*0OK7AVM_FGQQAIAZ,V+;[=1DU'RM2^/`````````
M````````````````````````G0(``!(`````````````````````````"`(`
M`!(`````````````````````````\P$``!(`````````````````````````
M``$``!(`````````````````````````:P(``!(`````````````````````
M````NP```!(`````````````````````````"@$``!(`````````````````
M````````O`$``!(`````````````````````````2`$``!(`````````````
M`````````````0```"``````````````````````````&`(``!(`````````
M````````````````9`(``!(`````````````````````````P`(``!(`````
M````````````````````]P```!(`````````````````````````<````!(`
M````````````````````````<@(``!(`````````````````````````:0$`
M`!(`````````````````````````PP$``!(`````````````````````````
M[@$``!(`````````````````````````$````"``````````````````````
M````L````!(`````````````````````````!0$``!(`````````````````
M````````B`(``!(`````````````````````````+````"``````````````
M````````````/0(``!(`````````````````````````>0(``!(`````````
M````````````````6P$``!(`````````````````````````G0```!8`````
M````````````````````YP```!(`````````````````````````C````!(`
M````````````````````````-P$``!(`````````````````````````1@``
M`!(`````````````````````````5@(``!$`````````````````````````
MCP(``!(`````````````````````````X0$``!(`````````````````````
M````RP$``!(`````````````````````````;@,``!(`````````````````
M````````=P$``!(`````````````````````````^0$``!(`````````````
M````````````@0(``!(`````````````````````````N`(``!$`````````
M````````````````LP$``!(`````````````````````````50```!(`````
M````````````````````(0$``!(`````````````````````````@````!(`
M````````````````````````+@(``!(`````````````````````````H@$`
M`!(`````````````````````````Z`$``!(`````````````````````````
MV@$``!(`````````````````````````/`(``!(`````````````````````
M````#P(``!(`````````````````````````T@$``!(`````````````````
M````````QP```!(`````````````````````````%0$``!(`````````````
M````````````M@(``!$`````````````````````````70(``!(`````````
M````````````````K@(``!(`````````````````````````8P```!$`````
M````````````````````(`(``!(`````````````````````````W````!(`
M````````````````````````*`$``!(`````````````````````````K`$`
M`!(`````````````````````````1`(``!(`````````````````````````
MF@$``!(`````````````````````````E@(``!(`````````````````````
M````E0$``!(`````````````````````````^`,``!$`%P!(`@(@`0````@`
M````````4@,``!*(#0#P70`@`0```&`"````````"@0``!*(#0`@+``@`0``
M`!@&`````````@0``!*(#0"@,@`@`0```)``````````_P(``!*(#0"`*@`@
M`0```%0`````````1@,``!*(#0#@*@`@`0```#P!````````T@,``!``%P!0
M`@(@`0``````````````P`,``!``&`!X`@(@`0``````````````(@,``!*(
M#0!`,@`@`0```%P`````````=P,``!*(#0`@0@`@`0```!0!````````MP,`
M`!*(#0#`6@`@`0```(0`````````[@(``!*(#0"`)P`@`0```!0`````````
M@P,``!``%0````(@`0``````````````ZP,``!*(#0"@)P`@`0```.`"````
M````V0,``!*(#0`@-0`@`0````0!````````FP,``!*(#0!0)@`@`0```%``
M````````A0,``"``%0````(@`0``````````````Q0,``!*(#0`P-@`@`0``
M```)````````JP,``!``&`!0`@(@`0``````````````7`,``!*(#0#0-``@
M`0```$@`````````,`,``!*(#0"@)@`@`0```-@`````````D`,``!*(#0!0
M6P`@`0```)P"````````40(``!*(#0"`&0`@`0```)0"````````HP,``"*`
M#0`@'``@`0```#P`````````I`,``!*`#0`@'``@`0```#P`````````#`,`
M`!*(#0`P/P`@`0```/`"````````A@$``!$`%P`X`@(@`0````0`````````
M`%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?
M9&5S=')U8W0`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?9F5T8VAP=@!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]L;V-K`%!,7V-U<G)E;G1?8V]N=&5X=`!P97)L
M7V%L;&]C`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?
M;F5W6%,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?9G)E90!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7W-Y<U]I;FET,P!097)L
M7VYE=UA37V9L86=S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`7TE/7W-T9&EN7W5S960`
M97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T
M`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R
M96%D`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D;&EN:P!R96%L
M;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB
M8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`<W1R8VAR`&UE;6-M<`!M96US
M970`;W!E;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N
M;U]L;V-A=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R
M:P!L:6)P97)L+G-O+C4N,S@`;&EB8RYS;RXV+C$`<&%R7V-U<G)E;G1?97AE
M8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?
M8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F
M:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?
M7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?<W1A<G0`7U]B<W-?
M<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'
M3$E"0U\R+C,N,@!'3$E"0U\R+C$`1TQ)0D-?,BXP``````(``@`"``$``@`!
M``$``P`!``$``@`"``0``0`!``(``0`"``(``0`!``(``@`!``4``@`!``$`
M`0`!``$``0`"``(``@`"``(``0`&``(``@`"``$``@`!``8``P`"``(`!0`"
M``(``0`!``(``@`"``$`!@`!``$``@`'``,``@`"``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!```````!
M``8`X@(``!``````````M)&6!@``!P`7!```$````!1I:0T```8`(@0``!``
M``"SD98&```%`"P$```0````<AEI"0``!``W!```$````!%I:0T```,`0P0`
M`!`````0:6D-```"`$T$````````8``"(`$````9````"0``````````````
M:``"(`$````9````"@``````````````N``"(`$````9````%```````````
M````V``"(`$````9````&```````````````^``"(`$````F````'```````
M``````````$"(`$````9````'0``````````````"`$"(`$````9````'@``
M````````````(`$"(`$````9````(0``````````````8`$"(`$````9````
M*0``````````````X`$"(`$````9````.@``````````````(``"(`$````:
M`````0``````````````*``"(`$````:`````@``````````````,``"(`$`
M```:`````P``````````````.``"(`$````:````!```````````````0``"
M(`$````:````!0``````````````2``"(`$````:````!@``````````````
M4``"(`$````:````!P``````````````6``"(`$````:````"```````````
M````<``"(`$````:````"P``````````````>``"(`$````:````#```````
M````````@``"(`$````:````#0``````````````B``"(`$````:````#@``
M````````````D``"(`$````:````#P``````````````F``"(`$````:````
M$```````````````H``"(`$````:````$0``````````````J``"(`$````:
M````$@``````````````L``"(`$````:````$P``````````````P``"(`$`
M```:````%0``````````````R``"(`$````:````%@``````````````T``"
M(`$````:````%P``````````````X``"(`$````:````&0``````````````
MZ``"(`$````:````&@``````````````\``"(`$````:````&P``````````
M````$`$"(`$````:````'P``````````````&`$"(`$````:````(```````
M````````*`$"(`$````:````(@``````````````,`$"(`$````:````(P``
M````````````.`$"(`$````:````)```````````````0`$"(`$````:````
M)0``````````````2`$"(`$````:````)@``````````````4`$"(`$````:
M````)P``````````````6`$"(`$````:````*```````````````:`$"(`$`
M```:````*@``````````````<`$"(`$````:````*P``````````````>`$"
M(`$````:````+```````````````@`$"(`$````:````+0``````````````
MB`$"(`$````:````+@``````````````D`$"(`$````:````+P``````````
M````F`$"(`$````:````,```````````````H`$"(`$````:````,0``````
M````````J`$"(`$````:````,@``````````````L`$"(`$````:````,P``
M````````````N`$"(`$````:````-```````````````P`$"(`$````:````
M-0``````````````R`$"(`$````:````-@``````````````T`$"(`$````:
M````.```````````````V`$"(`$````:````.0``````````````Z`$"(`$`
M```:````.P``````````````\`$"(`$````:````/```````````````^`$"
M(`$````:````/0````````````````("(`$````:````/@``````````````
M"`("(`$````:````/P``````````````$`("(`$````:````0```````````
M````&`("(`$````:````00``````````````(`("(`$````:````0@``````
M`````````@"[)]AGO2,^%<)#2(!]IP``7K<(`+ZW`@!@YP!`6VL(`+ZG``#^
M+P``7J<(`+ZG'A3"0P&`^FLY!7Q#`@"<)WD%.4-LYYPC``!\IQD$.4,(`)RG
M``#[:_?_G\/^___#_?__P_S__\/[___#^O__P_G__\/X___#]___P_;__\/U
M___#]/__P_/__\/R___#\?__P_#__\/O___#[O__P^W__\/L___#Z___P^K_
M_\/I___#Z/__P^?__\/F___#Y?__P^3__\/C___#XO__P^'__\/@___#W___
MP][__\/=___#W/__P]O__\/:___#V?__P]C__\/7___#UO__P]7__\/4___#
MT___P]+__\/1___#T/__P\___\/.___#S?__P\S__\/+___#RO__P\G__\/(
M___#`@"[)Z!FO2.P_]XC`03P1]B!?:<P`!XB,``^L```7K<X`#ZV.``^(D``
M7K9``%XB"``^M1``7K48`'ZU`$!;:P(`NB=@9KTC0(!=INB`':8``/XO$03R
M1Y\10-,``/XO``#^+\"!/:0``"$H6@`@Y```/26>````V(`]I`$$($`P`%ZA
M``!!I*B!?:<0D$!!"G!`07H$(BA0%@!"`70@1'H$(C@`0%MK`@"Z)S@`?J3X
M9;TC```])```O20``$.D*(+!I#``GJ`3!.!'``!`M/[_721KXT(@!``_(`@`
M0+3^_UTD2((%M&[C0B`0`,"TI3V`0!@`0+0-`*#T!7"`0`@`8R`&!.5''P3_
M1P``_B\``(.D0@8S0`$P($`(`&,@``""M*(%)4#Y_U_D`0#F0T$&,T#^_STF
M4(()IC"`?:<4!/]'$@3J1P``X;>@I3$B`$!;:P(`NB=,9;TC,```Y%""":90
M@7VG`$!;:P(`NB<T9;TC(``^(O[_'28*!.!'-^$0(@``_B^?`$#3``#^+P``
M_B\H``#D4(()IAB`?:<`0%MK`@"Z)_QDO2/0@'VG`$!;:P(`NB<(`#ZE``3J
M1P``7J<0`%ZE&`!^I>QDO2-0`-XC`8#Z:Z"`?:<`0%MK`@"Z)\!DO2,0!.!'
M```])5""";0C``#D^(!]IP!`6VL"`+HGH&2](YX```#8@#VD`@0@0```0J1N
M">([E___PU""":9H@'VG`$!;:P(`NB=T9+TCRO__PP``?25`@@NF!0``Y@``
M_B^7"4#3``#^+P``_B_0___#_O\=)B``/B+LX!`B``#^+V<`0-,``/XO``#^
M+T"""[00!.!'QO\?Y/#__\,`@GVG`0`?(@!`6VL?!/]'``#^+Q\$_T<``/XO
M``"@PP(`O2?\8[TC/A7"0P\4X$<(@AVF$``^HA@`7B(3!/]'%`3_1Q4$X$<`
M`-ZWZ(%]IP!`6VL```````#^+P(`NR?`8[TC\/_>(___'2;P?Q`B__\])```
M7K?P?R$@H04P0`4`(/28@'VG`P!@YP!`6VL"`+HGC&.](P``7J<0`-XC`8#Z
M:Q\$_T<``/XO`@"[)W!CO2/__QTF__\])O!_$"+P?S$B,04P0O#_WB.!=R!*
MD?8G2@``7K<1!"%"D3<@2@4`(.:X@'VG`P!@YP!`6VL"`+HG+&.](P``7J<0
M`-XC`8#Z:Q\$_T<``/XO`@"[)Q!CO2/P_]XC"``^M0``/24P@BDH``!>MP8`
M(/0``/XOS/]?TP``_B\``/XO`0`_(#""*3@``%ZG"``^I1``WB,!@/IK'P3_
M1P``_B\"`+LGP&*](P``_B_2___#'P3_1P``_B\?!/]'``#^+P(`NR>@8KTC
MP/_>(P@`/K4)!/]'(`">M0P$\4<H`+ZU#03P1P``7K<0`%ZU&`!^M3``WK4=
M``#F0($]I```P:4:`,#E```P*`L$_T<!`.%SHK4G0*$#X4.B%4!``0`B1!\`
M(/0``"ZE$``@Y0H$[D>X@7VG$@3K1Q$$[4<0!.E'`$!;:P(`NB<<8KTC`00K
M00,``/0``"$HH;4G0!P`(/0(`"JE"`!*(?'_/_4`!.E'``!>IP@`/J40`%ZE
M&`!^I2``GJ4H`+ZE,`#>I4``WB,!@/IK``#^+Q\$_T<``/XO"P3P1P$`*R@!
M`&LA`0#A<Z*U)T"A`^%#HA5`0`$`(D3X_S_T*P%M0=;__\,``/XO*@5.00$`
M:R&*=T!)"00K00``3+'A___#'P3_1P``_B\"`+LG<&&](V#_WB.(@7VG"``^
MM1``/B(``%ZW"03P1P!`6VL"`+HG3&&](Q```/0!`%\D.`!^H`#P(B`!`"-$
M`*!B("'V(4@`0%\@H@4B0*$%(T`!!$%$#0`@]```7J<(`#ZEH`#>(P&`^FL`
M`/XO``!>IP@`/J4`!/]'H`#>(P&`^FL``/XO'P3_1P``_B^P@'VG$`3I1P(`
M/R(`0%MK`@"Z)P@`/J4``%ZGH!4`0-!@O2.@`-XC`8#Z:P``_B\"`+LGL&"]
M(T#_WB,(`#ZU"03P1P``7K<0`%ZU&`!^M2``GK4"``#F```P*`@`(/0``%ZG
M"``^I1``7J48`'ZE(`">I<``WB,!@/IK``#^+\B`?:<`0%MK`@"Z)UA@O2,*
M!.!'\O\?Y'"!?:<0!.I'`$!;:P(`NB<\8+TC3```Y!,`("@3`&`A(=$E0"+V
M(4@!`$#T`0`K*`$`X4/R_S_D$P`@*"'1)4`B]B%(!`!`]`$`*R@AT25`(O8A
M2%``0.0!`.%#Z/\_Y!"!?:<0!.E'`$!;:P(`NB?<7[TC$`3K1Q"!?:<,!.!'
M`$!;:P(`NB?$7[TC$`"`05B!?:<04`!"`$!;:P(`NB>L7[TC%03K1_[_?2;(
M@7VG%`3I1YC@<R+__U\B`0`_(A`$X$<,!.!'`$!;:P(`NB=\7[TC$`3L1\"`
M?:<P`#XB`$!;:P(`NB<!```@9%^](Q`$[$<'``#D6``^H`$`7R0`\$(@`0`B
M1"'V(4@`P"$@)0`@Y!B!?:<`0%MK`@"Z)RQ?O2.H@'VG$`3L1P!`6VL"`+HG
M&%^](['__\,``/XO'P3_1P``_B](@7VG$`3J1P!`6VL"`+HG]%Z](Q`$Z4=X
M@7VG`$!;:P(`NB<(`#ZE``!>IQ``7J48`'ZE(`">I>!>O2/``-XC`8#Z:P``
M_B\?!/]'``#^+P(`*RBN___#'P3_1P``_B\``/XO?/]?TP``_B\``/XOVO__
MPP``_B\?!/]'``#^+P(`NR>`7KTCL/_>(Q"!?:<``%ZW"``^M1``7K4*!/!'
M&`!^M2``GK4H`+ZU,`#>M3@`_K4``#$HH;4G0`D$(4(0!.E'`$!;:P(`NB<X
M7KTC0``^(A`$ZD<+!.!'``#^+^'^7],``/XO``#^+PP$X$=C``#D$(%]IQ`$
MX$<`0%MK`@"Z)P!>O2.@!V!!3```]$``OJ%`@=VE31:@00``*B@0!/]'`0#A
M<Z*U)T"A`^%#HA5`0`$`(D0*`"#D$`3J1P$`,"@!`!`B`0#A<Z*U)T"A`^%#
MHA5`0`$`(D3X_S_T,`$*0@``+J0"`&LA6(%]IQ`$<$$+!"U``$!;:P(`NB<`
M``NTA%V](R,``.0``"ZD``"**`$`"B("`.1S`00M0```8:2AM4=`H14@0*(#
MXD,``(,X`0`B1`L`(.0``/XO``"0*`$`8R`!`!`B`0#D<P``@SBBM2=`HA5`
M0*$#X4,!`")$]O\_]#T`7R`!`",@``!#.```_B\?!/]'``#^+P``22@!`"$@
M`0`I(0,`XG/__T$X^O]_]```7J<(`#ZE$`!>I1@`?J4@`)ZE*`"^I3``WJ4X
M`/ZE4`#>(P&`^FL``"DH`0",(0$`*2$"`.%S__\L./#_7^0``"DH`0",(0$`
M*2$"`.%S__\L./3_7_3I___#``#^+Q\$_T<``/XO0('=I0``[J4``"^D,@`@
MY`$$[T<,!/]''P3_1P``_B\(`$&D`P3L1P@`(2`,,(!!^_]?]`-P8$!1%F!`
M```])#B"0:`:`$#T`0!?(%B!?:<X@D&P$`3Q1P!`6VL"`+HG)%R](\S_'^1-
M%H!!F(%]IQ$$[T<2!.U'$`3@1P!`6VL"`+HG`%R](P$$X$<```ZT0`">L0PP
M@$%,!H%!``#LMW[__\,``/XO'P3_1P``_B]0@'VG$`3O1P!`6VL"`+HG```.
MM,1;O2,!!.!'LO\?Y$T6@$'N___#$``_(@P$_T?6___#``#^+Q\$_T<``/XO
M`@"[)Y!;O2,`\/ZWX._>(Q@`?K4+!/!'D(%]I_[_'28(`#ZU_P]?(A``7K6>
MX!`B``!>MPH$\4<@`#XB`$!;:P(`NB<)`.!#4%N](P8`(.TA,2!!(`!^(`($
M84```$(H%P!`]!(`(/38@#VDG@```("`?:<2!.I'``0!0!$$ZT<```"F`$!;
M:P(`NB<(`#ZE``!>IQ``7J48`'ZE"%N](R`0WB,!@/IK'P3_1P``_B\)!.%'
M``#^+Q\$_T<``/XOL(%]IQ($Z4<O`#\B(``>(@!`6VL"`+HGO%J](^+_'^38
M@#VDG@```"B!?:<3!.E'``0!0!$$ZT<```"F(`!>(@!`6VL"`+HG"``^I0``
M7J<0`%ZE&`!^I8Q:O2,@$-XC`8#Z:P``_B\?!/]'``#^+P(`NR=@6KTCV(`]
MI/#_WB.>``````!>MP@`/K4)!`%````)IN"`7:;^_WTF_O\])M"!?:?H(',B
MK>`Q(@!`6VL"`+HG(%J](P``":;^_YTF_O]=)FKCE"+^_STF\(!]IQ4$_T<3
M!/1'$+]2(LG@,2(`0%MK`@"Z)P@`/J4``%ZG[%F](Q``WB,!@/IK``#^+P(`
MNR?06;TCV(`]I/#_WB.>``````!>MP`$`4#@@%VF````IO[_?2;^_STFT(%]
MI^@@<R*MX#$B`$!;:P(`NB<``%ZGE%F](Q``WB,!@/IK`@"[)X!9O2,`\/ZW
MX-_>(PB`?:<``%ZW"``^M0!`6VL"`+HG8%F](Q0$X$?^_[TF_O]])LB!?:>I
MX+4BWN!S(@$07R(!`#\B$1`>(@!`6VL"`+HG,%F](P`07R*0@7VG$``^(A$0
M'B(`0%MK`@"Z)PD`X$,46;TC`03_1Q$`(.E8@7VG$#`@00!`6VL"`+HG]%B]
M(P$$X$<*``#D"(%]IQ($Z4<0`#XB$`3@1P!`6VL"`+HG"00)0-!8O2,``.D[
M`03@1P``7J<(`#ZE``3A1R`@WB,!@/IK'P3_1P``_B\"`+LGH%B](P``_B_&
M___#'P3_1P``_B\?!/]'``#^+P(`NR>`6+TC`/#^MR#OWB,@`%ZU"@3P1R@`
M?K7^_QTF[.`0(@L$\4<0`%ZW4``^(A@`/K4P`)ZU.`"^M4``WK5(`/ZU``#^
M+V?]7],``/XO``#^+UB`?:<O`#\B$`3J1PD$X$<`0%MK`@"Z)QA8O2,3``#D
M_O\=)A$$ZD?UX!`B``#^+V#^7],``/XO``#^+P`$ZD<0`%ZG&``^I2``7J4H
M`'ZE,`">I3@`OJ5``-ZE2`#^I>`0WB,!@/IK``#^+^"!?:<0!.M'`$!;:P(`
MNB>T5[TC$`3@1_[_?26`@7VG`N%K(1$$ZT<`0%MK`@"Z)Y17O2,/!.!'WO\?
MY```+RC^_[TE`0#?)03AK2%2`"#D!P`@Y?B!?:<1!.]'$`3I1P!`6VL"`+HG
M7%>](T```.00@7VG$`3O1P!`6VL"`+HG__\@($17O2,!!.%!#`3@1Z,#X4$&
M`&#T#@#@PP``_B\``.$[__\A(*(%X4$#`$#T``!!**+U14#Y_U_T$(%]IQ`$
M[T<`0%MK`@"Z)_A6O2,,!.!'$(%]IQ`$ZD<`0%MK`@"Z)P$$#$#_#U\@`0`A
M(.!6O2.A!R)`KO\_Y/[_?2;(@7VG%03M1Q0$[T<(XG,B`!!?(@$`/R)0`!XB
M``!>M0!`6VL"`+HGG%:](U`0/B+`@'VG4``>(@!`6VL"`+HGA%:](PH``/1X
M$#Z@`0!_)`#P8R``@$X@(O9!2`$`(T0A]B%(H04B0!D`(/0``/XO@(%]IQ$$
MZT<0!/]'`$!;:P(`NB=`5KTC#P3@1XG_'^0``"\HKO\_]`<`(.4``"DH(=$E
M0"+V(4@!`$#T`0`I*`$`X4/N_S_D_O^=)@$`GR'JX/0AP___PQ\$_T<``/XO
ML(!]IP$`/R)0`!XB`$!;:P(`NB?@5;TCX?\?]/[_'290`#XB]>`0(@``_B_2
M_5_3``#^+P``_B_@@7VG4``>(@!`6VL"`+HGK%6](VW__\,"`+LGH%6](_#_
MWB.(@'VG``!>MR\`/R((`#ZU"03P1P!`6VL"`+HG?%6](P$``"*0!`E$X(%]
MIP!`6VL"`+HG"``^I0``7J=D5;TC$`#>(P&`^FL``/XO'P3_1P``_B\"`+LG
M0%6](P#P_K?@[]XC$`!>M0H$\$<``%ZW"``^M3L``.8``#`H.0`@Y!"!?:<`
M0%MK`@"Z)P$`0"(`$#\@"03@1PQ5O2,`!/]'H0=!0B<`(.0(@7VG$03J1R``
M'B(`0%MK`@"Z)R``7B#__RD@`01!0-Q4O2.B`T%`"0!`]`L`X,,``/XO'P3_
M1P``_B\``.$[(`!^(/__(2"B!6%``P!`]```02BB]45`^/]?](B`?:<O`#\B
M(``>(@!`6VL"`+HG@%2](Q$``.0@`%X@H0-`0`$`(.0``.`[X(%]IR``'B(`
M0%MK`@"Z)UA4O2,``%ZG"``^I1``7J4@$-XC`8#Z:P``_B\?!/]'``#^+_[_
M'2;@@7VGZN`0(@!`6VL"`+HG"``^I0``7J<0`%ZE(%2](R`0WB,!@/IK``#^
M+P(`NR<`5+TCL/_>(P@`/K7^_STE$`!>M0;A*2$``%ZW&`!^M2``GK4H`+ZU
M,`#>M4"!7:5``#XB$`3I1P``_B])_%_3``#^+P``_B\3``#D``!*I$``/J!!
M!B)`"`!!I```0;3S_U_D'P3_1P``_B\0`$&D"``A(```0;3\_U_T0``^(A`$
MZ4<``/XO-OQ?TP``_B\``/XO[?\?]/[_/25`@5VE#^$I(4``/B(0!.E'``#^
M+RS\7],``/XO``#^+Q(``.0``$JD0``^H$$&(D`(`$&D``!!M//_7^0``/XO
M$`!!I`@`(2```$&T_/]?]$``/B(0!.E'``#^+QK\7],``/XO``#^+^[_'_3^
M_STE0(%=I1?A*2%``#XB$`3I1P``_B\0_%_3``#^+P``_B\2``#D``!*I$``
M/J!!!B)`"`!!I```0;3S_U_D``#^+Q``0:0(`"$@``!!M/S_7_1``#XB$`3I
M1P``_B_^^U_3``#^+P``_B_N_Q_T_O\])4"!7:4@X2DA0``^(A`$Z4<``/XO
M]/M?TP``_B\``/XO$@``Y```2J1``#Z@008B0`@`0:0``$&T\_]?Y```_B\0
M`$&D"``A(```0;3\_U_T0``^(A`$Z4<``/XOXOM?TP``_B\``/XO[O\?]/[_
M/25`@5VE)^$I(4``/B(0!.E'``#^+]C[7],``/XO``#^+Q(``.0``$JD0``^
MH$$&(D`(`$&D``!!M//_7^0``/XO$`!!I`@`(2```$&T_/]?]$``/B(0!.E'
M``#^+\;[7],``/XO``#^+^[_'_3^_UTE0(%]I3?A2B%``#XB$`3J1P``_B^\
M^U_3``#^+P``_B\2``#D``!+I$``/J!!!B)`"`!!I```0;3S_U_D``#^+Q``
M0:0(`"$@``!!M/S_7_1``#XB$`3J1P``_B^J^U_3``#^+P``_B_N_Q_T_O]=
M)4"!?:7LX$HA0``^(A`$ZD<``/XOH/M?TP``_B\``/XO$@``Y```2Z1``#Z@
M008B0`@`0:0``$&T\_]?Y```_B\0`$&D"``A(```0;3\_U_T0``^(A`$ZD<`
M`/XOCOM?TP``_B\``/XO[O\?]/[_G25`@7VE0^&,(4``/B(0!.Q'``#^+X3[
M7],``/XO``#^+Q(``.0``$ND0``^H$$&(D`(`$&D``!!M//_7^0``/XO$`!!
MI`@`(2```$&T_/]?]$``/B(0!.Q'``#^+W+[7],``/XO``#^+^[_'_3^_WTE
M0(&]I4WA:R%``#XB$`3K1P``_B]H^U_3``#^+P``_B\2``#D``!-I$``/J!!
M!B)`"`!!I```0;3S_U_D``#^+Q``0:0(`"$@``!!M/S_7_1``#XB$`3K1P``
M_B]6^U_3``#^+P``_B_N_Q_T_O^])4"!W:57X:TA0``^(A`$[4<``/XO3/M?
MTP``_B\``/XO$@``Y```3J1``#Z@008B0`@`0:0``$&T\_]?Y```_B\0`$&D
M"``A(```0;3\_U_T0``^(A`$[4<``/XO.OM?TP``_B\``/XO[O\?]/[_O25`
M@=VE]>"M(4``/B(0!.U'``#^+S#[7],``/XO``#^+Q(``.0``$ZD0``^H$$&
M(D`(`$&D``!!M//_7^0``/XO$`!!I`@`(2```$&T_/]?]$``/B(0!.U'``#^
M+Q[[7],``/XO``#^+^[_'_3^_QTF0``^(F'A$"(``/XO%OM?TP``_B\``/XO
M$03@1P4``.00!.M'``#^+Q?\7],``/XO``#^+_[_'29``#XB<N$0(@``_B\(
M^U_3``#^+P``_B\1!.!'!@``Y/[_'2:$X1`B``#^+PC\7],``/XO``#^+_[_
M'29``#XBC^$0(@``_B_Y^E_3``#^+P``_B\1!.!'$@``Y!`$ZD<``/XO^OM?
MTP``_B\``/XO$`3I1_[_/28``%ZG"``^I1``7J48`'ZE(`">I2@`OJ4P`-ZE
ML.$Q(E``WB,``/XOZ_O_P_[_'29``#XBG^$0(@``_B_>^E_3``#^+P``_B\1
M!.!'ZO\?Y!`$[$<``/XOW_M?TP``_B\``/XOY/__PQ\$_T<``/XO`@"[)^!-
MO2/@_]XC_O\=)A``/B)#X1`B``!>MP``_B_)^E_3``#^+P``_B\!!.!'``3_
M1P8`(.0``"$H`0#A<Z`5)D"A%2!```0!1``X`$0``%ZG(`#>(P&`^FL``/XO
M`@"[)X!-O2-P_]XC"``_("@`/K`#!/!'`(&=I"@`7J0``%ZW8``^(```!*8P
M@7VG:``^M@$`/R)P`%ZV$@3C1W@`?K83!.%'@`">MA0$XD>(`+ZV.``^GD``
M7IY(`'Z>4`">GE@`OIX@`#ZT$``^M!@`7K0`0%MK`@"Z)PA-O2/_`!\B`()]
MIP!`6VL?!/]'`@"[)_!,O2,(`/\B`!#>(@#@]K<W->!"`.#6(OS___;`[]8C
M\(%]IQ``7K4"`%\B&`!^M1$$_T<@`)ZU#`3P1R@`OK4!`+\E``!>MP@`/K4`
M0%MK`@"Z)___8"&<3+TC@O=G2?__726"%D9(X']*(0$$8D$A=B!((04B0"L%
M84&A&6!!.0`@]!\$_T<``/XO\(%]IQ($_T<1!.M'$`3L1P!`6VL"`+HG`0``
M($Q,O2,T``#DD(!]IP@`32(P`#XB$`3L1P!`6VL"`+HG``#@0RA,O2,!`"`@
M)@`@Y*'W`$`?`"#T,``^(/C_`"`)!"!`H0<I0`8`(/09`.##``#^+___*2$P
M`%X@H0=)0!0`(.0@@'VG"`!?(A$$ZD<0!.E'`$!;:P(`NB?,2[TC]/\?]#``
M/B`@!2%!``0+0```7J<(`#ZE$`!>I1@`?J4@`)ZE*`"^I0$`_B9``-<C`8#Z
M:___:R4!`"LDR?\_]/__'R#R___#_O\=)K_A$"(``/XO??]?T_[_'2:RX1`B
M``#^+WG_7],?!/]''P3_1P``_B\"`+LG4$N](_#_WB,X@7VG``!>MP!`6VL"
M`+HG.$N](Q``X$,@@7VG`$!;:P(`NB<D2[TC`0``Y````*0``%ZG$`#>(P&`
M^FL?!/]'``#^+P(`NR<`2[TCL/_>(R``7K7^_UTER^%*(4``/B(H`'ZU"P3P
M1Q@`/K40!.I'$`!>MS``GK4``/XO"_I?TP``_B\``/XO"03@1P(``.0``"`H
M"P`@]!$$ZT<0!.I'$`!>IQ@`/J4@`%ZE*`!^I3``GJ50`-XC``#^+P/[_\,`
M`/XO$(%]IQ`$ZT<`0%MK`@"Z)W1*O2,0!.E'$(%]IPP$X$<`0%MK`@"Z)UQ*
MO2,0!(!!6(%]IP(`$"(`0%MK`@"Z)P``/K5$2KTC`0`_(O[_O2;^_WTFR(%]
MIP+AM2(4!.M'".)S(O__7R(0!.!'#`3@1P!`6VL"`+HG#$J](Q$$[$?5___#
M``#^+Q\$_T<``/XO`@"[)_!)O2/^_STDH/[>(^+A(2!@`#XB,`$^M/[_/21(
M`+ZUZN`A(#@!/K3^_STD?>$A(`T$\$?P`#ZT_O\]).?A(2#^_QTF^``^M/[_
M/22:X2$@[.`0(@`!/K3^_STD(`!>M^_A(2`(`3ZT_O\])"@`/K7SX2$@&`$^
MM/[_/20P`%ZU^.$A(#@`?K5``)ZU4`#>M5@`_K5``?ZW$`'^MR`!/K0H`?ZW
M``#^+ZKY7],``/XO``#^+P(``.0``"`HHP$@]#B!?:<`0%MK`@"Z)R1)O2,0
M`.!#((%]IP!`6VL"`+HG$$F](\$``.0``("EOP"`Y1"!?:<0!.Q'`$!;:P(`
MNB?P2+TC$`0`0%B!?:<!`!`B`$!;:P(`NB<``(PJV$B](PX$X$<*!.!'%`#T
M<Q$`@.;^_STE__]_(0'B*2'(@7VG%/"?1A`$[D<3!.E'$@3K1P$`/R(`0%MK
M`@"Z)P$`C"$``(PJE$B](P(`SB$4`/1S\O^?]O[_'2;H`'XAA.$0(@4`X,,?
M!/]'``#^+P@`"Z8(`&LA&0``YF``/B(``/XO;/E?TP``_B\``/XO"03@1_;_
M'^0``"`H]/\_Y!`$X$<``/XOK_E?TP``_B\``/XO[O\?Y."!?:<0!.E'`$!;
M:P(`NB<,2+TC"03@1Q,``/0``/XO'P3_1P``_B\P`7XA```KI0T`(.4``"DH
M<P`@Y!`$Z4<``/XOFOE?TP``_B\``/XO80``]`@`*Z4(`&LA]?\_]1\$_T<`
M`/XO$(%]IQ`$Z4<`0%MK`@"Z)Z1'O2,0!.I'$(%]IPX$X$<`0%MK`@"Z)PX`
MP$&,1[TC!`3.(5B!?:<.`.Y#$`3N1P!`6VL"`+HG"`!>M6Q'O2,4!.E'_O^=
M)?[_/20/XB$@_O]])LB!?:<$X8PA%03L1P;B<R(``#ZT__]?(@$`/R(0!.!'
M"P3@1P!`6VL"`+HG)$>](\`!/R(0@'VG$`3K1P!`6VL"`+HG`0``(`Q'O2,'
M``#T`(!]IP!`6VL"`+HG``"@HO1&O2.A-:)"`P$@Y(B!?:=@`#XB$`3K1P!`
M6VL"`+HGT$:](PD$X$<'``#TB``^H`$`7R0`\$(@`0`B1"'V(4@`P"$@30`@
MY`"!/:3^_UTF``!MIFB!?:<```&F%`3K1T_B4B(!`#\B`$!;:P(`NB>`1KTC
M"@3_1P`$ZD<@`%ZG*``^I3``7J4X`'ZE0`">I4@`OJ50`-ZE6`#^I6`!WB,!
M@/IK'P3_1P``_B_@@7VG$`3I1P@`:R$`0%MK`@"Z)S!&O2,)!.!'C?\?Y)O_
M_\,``/XO'P3_1P``_B\)!/]'EO__PQ\$_T<``/XO&`$>IA@!/B$-``#F``#^
M+V``/B(``/XOT_A?TP``_B\``/XO$`3@1P(``.0``"`H#P`@]`@`*2$```FF
M]/\?]EB!?:<-`!\B`$!;:P(`NB>T1;TC#@3@1_[_G24*!.!'V^&,(5,`GR(V
M___#``#^+^"!?:<`0%MK`@"Z)XA%O2,,!.!''_\?]`@`*2'J___#.(%]IXP`
M7J$`0%MK`@"Z)RKV04DA]@%(9$6](ZH%04&J_U_EB`!>H/\!/R`!`")$0/XA
M(*7_/_18@7VG$`3N1P!`6VL"`+HG+$6](V``/B+^_QTF"@3@1];A$"(``/XO
MG?A?TP``_B\``/XO$03@1Z<``.0```VF``#^+Q[[7],``/XO``#^+PX$X$>@
M``#D$(%]IQ`$[D<`0%MK`@"Z)P\`X$/41+TCH7W@01``(/3^_STF_/\/(OB!
M?:>BXC$B$`3000!`6VL"`+HGJ$2](P<``/2AE>!!T0`@]"&QX$$!!,%!```A
M**'U)4#,`"#T_O^])6``/B)#X:TA$`3M1P``_B]T^%_3``#^+P``_B\&``#D
M```@*`$`X7.B%2!`H14F0`$$040(`"#D.(!]IQ`$[D<1!/]'`$!;:P(`NB<T
M1+TC#@3@1W,``/3^_STF$`3M1[#A,2+``?\A``#^+V7Y7],``/XO``#^+PB`
M?:<`0%MK`@"Z)_Q#O2,5!.Q'_O^])?[_?29JXZTAR(%]IP@`OK44!.M'```>
MM,;B<R+__U\B`0`_(A`$ZD<`0%MK`@"Z)\!#O2/^_]TEU.+.(1P`X,,``/XO
M'P3_1P``_B\`@'VG`$!;:P(`NB<``""@F$.](Z$U(D`:`"#D"(!]IPDP($$`
M0%MK`@"Z)Q``OK5X0[TC%03L1\B!?:<4!.M'"``^M1,$[D<``!ZT__]?(@$`
M/R(0!.I'`$!;:P(`NB=$0[TC$(!]IQ$$[T<0!.I'`$!;:P(`NB<!```@+$.]
M(]__'^2H@'VG$`3K1P!`6VL"`+HG$$.](Q$$ZD?^_QTF[.`0(@``_B\?^5_3
M``#^+P``_B\0!.I'``#^+_K]7],``/XO``#^+QC__\,`@3VD_O]=)@``;:9H
M@7VG```!IA0$ZT<4XE(B`0`_(@!`6VL"`+HGL$*](PO__\,``/XO4`$>M!`$
MX$<``/XOYOU?TP``_B\``/XO4`$>I."!?:<0!.!'`$!;:P(`NB=X0KTC"@3@
M1_W^_\,?!/]'``#^+P``S:5>___#$`3@1P``_B]9_5_3``#^+P``_B\/!.!'
MAO\?Z/"!?:<2!/]']O\@(A`$[D<`0%MK`@"Z)RA"O2,&`%\BD(!]IT@!/B(0
M!.Y'`$!;:P(`NB<,0KTCH=4`0#X`(.3^_STF((!]IP8`7R+A(#$B2`$>(@!`
M6VL"`+HGY$&](VW_'_3P@7VG$@3_1\[_+R(0!.Y'`$!;:P(`NB?$0;TC*`!?
M(I"`?:=@`#XB$`3N1P!`6VL"`+HGJ$&](Z$5!4`E`"#D_O\])/[_?29JXR$@
MR(%]IP@`/K1@`#X@%03L1Q0$ZT<``#ZTM^)S(O__7R(!`#\BB`#^.Q`$ZD<`
M0%MK`@"Z)UQ!O2.-___#"`"MI3+_O^40@7VG$`3M1P!`6VL"`+HG/$&](Z%W
M`$`K_S_T_/\`(/[_/2;X@7VGI^(Q(A`$H$$`0%MK`@"Z)XX$#4040;TC(?__
MP_[_'2:LXA`B``#^+]_\7],?!/]'`@"[)_!`O2/`_]XCG@````@`/K7^_QTF
MV(`]I3``/B(0`%ZU)^$0(@``7K<!!"!!&`!^M0H$X$<@`)ZU``!AI;``*RBQ
M`"LX``#^+X+W7],``/XO``#^+P,``.0``"`HH34F0((`(/0``/XO(OM?TP``
M_B\``/XO`00J00``8:7^_STF<(!]IQ`$ZT<#`'\B`0!?(N7B,2(`0%MK`@"Z
M)U1`O2,+!.!'$```Y!``(*0,!"I!_O]=)@``#*8``"&F@(!]I^?B4B(`0%MK
M`@"Z)Q``*Z0D0+TC```AID``/R0,`%&@`0`B1'$`(/0,!"I!_O\])@``#*9P
M@'VG`P!_(@$`7R+LXC$B`$!;:P(`NB?D/[TC"P3@1Q```.3^_QTF,``^(O7@
M$"(``/XO2O=?TP``_B\``/XO$@3@1U```.00`"ND```,IH"`?:<``"&F`$!;
M:P(`NB></[TC"00J0?[_/28``$FE*(!]IP$`7R+NXC$B$`3J1P!`6VL"`+HG
M=#^](Q$$X$?^_UTF@(!]IQ`$ZD<#XU(B`$!;:P(`NB=4/[TC```II/[_'28P
M`#XB[.`0(@``726Q`.$[``#^+R7W7],``/XO``#^+T"""K0)!.!'%@``Y!"`
M?:?``3\B$`3I1P!`6VL"`+HG`S``0*(U`D`C]F%(`0`_(*(50$"A`R-`"#^]
M(P$`(D0N`"#T``!>IP@`/J40`%ZE&`!^I2``GJ5``-XC`8#Z:P``_B\``#TD
M2((!I@``_B\R_5_3``#^+P``_B]`@@JT"03@1^'_'_3^_QTFH(%]IPGC$"(`
M0%MK``#^+Q\$_T<``/XO`0`@*(+_/^1[___#``#^+P``/200`$ND2((AI```
M`J8``"&F``#^+[/X7],``/XO``#^+ZW__\,?!/]'``#^+P``#*9@@7VG`$!;
M:P(`NB<T/KTCB?__PP``/23^_QTF2((AI*"!?:<3!.!'$@3I1P``(:8JXQ`B
M`$!;:Q\$_T<"`+LG`#Z](]#_WB,(`#ZU"03P1_[_'28@`#XB``!>MT/A$"(0
M`%ZU``#^+\[V7],``/XO``#^+PD``.0``"`HH@/I0P$`X7.C%29`H14@0`,$
M840#.&!$`0!#1`@`(/0``%ZG"``^I1``7J4P`-XC`8#Z:P``_B\?!/]'``#^
M+P``*2CV_S_D$`3I1P``_B\-^E_3``#^+P``_B^(@'VG+P`_(A`$X$<*!.!'
M`$!;:P(`NB=0/;TC`0``(I`$"D3@@7VG`$!;:P(`NB<X/;TC$`3@1_[_/2:X
M@7VG!`!?(@_B,2(`0%MK`@"Z)Q@]O2/;_Q_T$`3I1P``7J<(`#ZE$`!>I3``
MWB,``/XO$O?_PQ\$_T<``/XO'P3_1P``_B^`_-XC.`#P($``?B!X`/`B``!>
MMP@$XT<(`#ZU$`!>M1@`?K4@`)ZU*`"^M3``WK4X`/ZU``#^+Q\$_T<``/XO
M``"'H```QZ00``@A"`#G(.+\@$BV!>="9'.`2($6Q4@$!$1$A1;$2((6@DB&
M%L=((58@2"16GT@!!"9$(K9>2&9QH$@"`$1`)1>A2`$$)D0EEJ!((O9!2`$$
M)43P_TBT^/\HM.;_W^:H`!ZGL`#^IK@`7J10`-ZF6``>I6``_J1H`-ZD<`"^
MI'@`/J<``H,C!`#@PP``_B\?!/]'``#^+QD$Y$=``(.D```CI`@`8R`!"(%$
M`0@X1!@$]T<!"#9$%P3B1P($(4`6!.A'@?8C2`@$YT<"!$%$!P3F1R+V04@&
M!.5'>`!#M`4$^4>A!7Q`Z_\_Y```T*9``-ZD@EH_)!``\*:#=L-*F7DA("*W
MP$H(`!"E&``0I`($0T0@`'"D!@3!0(56`$D$".!&!@3#0`0`B$0CUP-)!`B`
M1`,$941(`+ZD(O9!2'``GJ8G]F%(`@1&0`($1$`$".=&(O9!2`4$H4`$`)9$
M!02@0)AV0T@$")=$)K=`2`0$A4`&!-A$%`2!0B77PTH$!(9`F5;`2E``WJ08
M!+E$T`#^I23V@4@#"'A$A7:#2`8$P4`#`&)$!@370#RW@$@#"&=$'`2%1P,$
M9D"%5D!(6`#>I#G70T@"!'Q`&00E1P8$P4`E]@%+`P@91V``'J<#`&1$(O9!
M2`8$QT`8!`%#`PAE1!@$!4,#!&9`AW9#2'@`GJ<EMT!(#P3A02;7@T@%!*=$
MA%:`2&@`_J0&!,1$`P1E0`0()D<'!.%`)?9A2`0`@D0C]B%+'`2!0P0(@T0'
M!.-`.;>@2`0$F$`CUT-(V`"^I9AVHTC@`)ZE@E9`2!D$.$<8!&)$!`290`,(
MV$2``#ZG)/:!2`,`940B]L%(&00A0Q0$@D(#"&)$)K>`2`,$9T""=H-(B`#^
MI`8$PD3H`'ZE@E:@2`,$9D`UUZ-(!P3A0!4$HD:0`+ZD`@@51_``7J4F]F%(
M`@!$1"/V`4L%!*%`'`2#0P((0T28=L-(`@140".WP$B8`)ZF,=>#2`,$>$2$
M5H!(`@1#0!$$)$84!(%"`PBQ1J``'J<D]D%(`P!F1"+VH4H8!`%#`PAB1!D$
M(D,#!'Q`^``^I9QV@T@``7ZG(K>`2`T$H4$UU\-(`@1<1(96P$@#!&)`%02F
M1J@`GJ<""#5&L`#>I`(`1$0<!(%#,?8A2@8$P4`C]F%(`@A11#/7@T@1!/%`
MA%:`2`($64`GMV!($P1D1IEV8T@$"+-&!P3Y1`0`@T0U]J%*`@1'0"+V04@$
M")5$$@2U0`0$D4`EMT!(N``^IY%V0TC``/ZD$02Q1!D$(4.%5F!(!P3A0#77
M8T@#!)%`%02E1L@`GJ0C]F%(!0AU1@4`HD0$!(%`,_9A2MIN/R0%"+-$$P23
M0@4$LD"AZR$@DG9C2`P$@4$QMV!("P1A01$$,D8*!$%!DE9`2`D$(4$TUT-(
M`@2Q0!0$DD8(`3ZF!0BT1AL$84,U]J%*!0"C1"+V04@%"+5$!02S0!@$%4.3
M=D-($00A0C*W0$@UUV-($@131I-68$@#!+)`%02S1A`!7J8C]F%(!0B51@4`
MHD02!$%"-/:!2AP$E$,%"+1$,[=@2`4$N$"4=F-(.-=#2!,$=$:45D!(`@2S
M0"+V04@8!!1'-+=`2`4(N$8U]J%*!0"C1`8$U4`%"+5$E79#2`4$O$`\UV-(
M%`251I568$@#!+1`(_9A2!P$E4<UMV!(!0@<1SCV`4L%`*)$!0BX1!D$.$,X
MUT-(!02F0(9V8T@5!*9&AE9`2`($M4`E]H%+&`0&1R+V04@&")A'!@##1!@!
MGJ<&",5$!03E0"?78T@&!-E`@U9@2"`!?J8'!.-$,`&>IC6W0$@#"`='F79#
M2`,`8D09!+E&$P1A0CCV`4L&!-E``PAX1`0$F$`F]L%(`P1E0"770T@H`3ZG
M@E9`2!0$@4*5=L-(!02B1#BWP$@"".5$&`051P(`1D0G]N%(`P1X0"/V84@"
M"$=$#P3G00($1$`GMV!(.`$>IX1V8TA``;ZF!P3D1!P$@4,DU\-(`@1'0(96
MP$@5!*%"!`2&1$@!WJ0B]D%(!PBD1`8$P4`'`.-$P`+>M!D$(4,E]J%(&`0!
M0XYV0T@'".5$)K=`2`T$I4$&!,Y$!P3O0";VP4@EUV-(!P3F0(-68$A0`=ZD
M!02C1`X(A40&!,%`(_;A2`X`PD4D]H%(R`+>M`X(Q$6/=F-(#@3-02:W8$@$
M!(1!+==#2%@!GJ6"5D!(!@3/1`($HD4/!(%!)O;!2`P$QD$&"*)$+?:!20<(
MQT0G]N%(8`'>I"ZWH$D'!.1`!@3!0'`!GJ30`MZT:`'>I`0$@4#@`IZT)?:A
M2`8$P4#8`MZT!01E089VHTD&!,9%)O;!2"[78T@$!.9`@U9@2'@!WJ0#!,-%
M!@3!0`$(0T3H`MZT`0@L1";V@4@GM\!(BW;#2"'V(4@+!.M$*_9A20$$H4`E
MUZ-)!P0K0(U6H$DK]N%(!02M1"+V04@!"&5$`@1"00$()$2*=F-))+=@22'V
M(4@*!(I$*O9!20$$04`BU\-(!`0J0(96P$@C]F%(`@1&1`$(HD0#!"-!)O:!
M2`$()T2)=L-()[?`2"'V(4@)!.E$*?8A20$$84`CUV-)!P0I0(M68$DI]N%(
M`P1K1"7VH4@!"$-$!01E0P$()$2;=B-))+<@22'V(4@;!)M$._9A2P$$H4`D
MU\-(!00[0(96P$@B]D%(!`2&1`$(9$0"!")")O:A2`$()T21=L-()[?`2"'V
M(4@1!/%$(_9A2`<$04`B]B%*,64_)`<$XD#K8"$@(`)>I`$$(4`QUR-)`P1#
M0HE6($D[]N%($00I1I)V8TL)!$%``@B11"3V@4@""$5$(O9!2!P$A$,EMV!+
M`@1B0!($LD0H`GZD,O9!2B77PT@*!&%`AE;`2`,$4D`P`EZD!02F1";V84@X
M`EZFA';#2`($04#P`EZT`@@E1@((1T02!$%")[?`2"+V04@$!.1$)/:!2`($
M@D,GUV-+'`1$0)M68$M``EZD,?8A2@0$^T0"!$%`$01Q0@`#7K0G]H%+2`)>
MI)-VXTCX`EZV`@1!0`@#7K0""*1$,M?#2`((0T0CM^!((O9!2!,$<T10`GZD
M`@0B0C/V84HE]J%(`P1A0!`#?K0#!%-`@E;`2%@"WJ0S]F%(&00E0X5V8TH&
M!,%`&`/>M`8$0D8""(9$8`)>IB3V@4@""%Q$/+=@2@0$A$(%!(5'B`*>IB+V
M04@2!$%"`@0B0Q0$@4(E]J%(/-?C2!D$14"'5N!(:`)>I"`#7K8%!(=')_8A
M2P($04`H`UZTG';C2'`"7J1(`YZV`@1!0#`#7K0"",5$)O;!2`((0T0CM^!(
M&`0&0R+V04@<!'Q$>`)^I`($@D`\]H%+)-=C2@,$84`X`WZT`P1<0)-68$J`
M`EZD//9A2`0$DT2&=H-+`@1!0$`#7K0""*1$)?:A2`((640YMX!+!02E0@8$
M)D?``KZF(O9!2";VP4@"!`)#.-?C2`8$1D""5N!(D`+^I`<$X4!0`_ZT!P0"
M1Y@"7J08"(=$)/:!2!@(`T<X]@%+`@1!0%@#7K08!+A`(O;!2".W0$B9=D-(
M)=>#2QD$>40Y]B%+H`)^I)Q6@$L8!!E#`P1A0`4$O$1@`WZT&0CE1*@"?J0&
M""9')O;!2!D$I$(#!&%`!@0F0V@#?K0C]@%+L`*^ICRW8$B$=F-(%02A0CG7
M0T@$!(1')/:!2()60$@$!,1`N`+>I`($(D<G]N%(P`*^M@8$P4`&!-9`T`*^
MIG`#WK0&"*)$(?:!2`8(V$0VMR!(R`(>IR;VP4@E]J%(!P0'0YAV(T@'!.9`
M%@381CC78TB#5F!(-O;!2@,$`T<&!/9`%@A#1"?VP4@6",1&F';C2`0$Y4$V
M]L%*);?@2`0$ED`VUR-(!02X1(%6($@E]J%(%@3!1@$(=D0$!(5`)?:!2`8(
M)D0B]D%(F':C2`$$HD(F]L%(X`*^IB*WH$@&!"9`(=?C2`($6$2'5N!(V`(>
MIR+V04@!!"=$!PC!1@8$PD`B]L%(!`CD1"/V84@D]H%(!P0#0SBW0$@$!.1`
M@W9#2(=6H$@#!`-'.->C2"7V84@#!`='!02%0`<((T0D]J%(!PCF1#;VP4HG
M]N%(!@2V0IAV@T@&!,=`-K>`2"?70T@8!-A&EE9`2`($V$`'!/9$Z`(>IR+V
M04@&"&=$(?8A2`8(Q40VMT!(`00!0R;VP4B%=D-(`00F0";7@T@%!,5&A%:`
M2`$$)4#'([\@!@3$1"57HD@$!.9$W+S%(8`!OJ0Y]L%(!`""1!8`^40%!*Y`
M(_9A2`0$ED0#!*-`B`'>IB'V(4B0`;ZD`P2#0!8$SD(DUT-(!02N0()60$@%
M!+E`!`2"1+`!OJ4\MR!(!@3$1)AV(T@&`,%$&`281QD`F40#!'A`&0391"?V
MX4B@`=ZD(_9A2!8$QT(UMV!(&00V0YQV8TB8`1ZGEE8@2!P$O$8BUR-(`00\
M0P($5D0&!,Y`.?9!2!8$@D0<`)E$%@##1A8$W$8&!-E`(?8A2!8$Q4(EUV-(
M&`0.0X-68$BH`?ZD!02C1`T$KD$UMR!(`@1%1)QV(T@9`+E$'`2\1@(`0406
M!-Q"!P3N0"3V@4BX`7ZE(_;!2A@$!$,6!%E$P`%^IR2W8$@6!-A"F'9C2,@!
M/J88!)A$T`%>IH16($C8`7ZF(M<C2`$$V$("!$1$X`&>IC;V04@$!*)$&`"V
M1`0`@T0$!)A$#02V02'V(4@$!(9`)M=C2.@!OJ:#5F!(\`&>IP8$PT0+!&Y!
M.;<@2`($1D28=B-(%@#61!@$.$<"`$%$!`280`,$5D0D]H%(^`$^IR7VH4@`
M`AZG(M<C2`<$Y4"!5B!(`P1G0"RW@$@"!$%$A7:#2`$$PD0%!(5%`0`D1"SV
M04@#!&5`!0#,1`@"WJ80`OZD`00E1!@"OJ0;!&Y#(_9A2!$$+D(OMV!($@1.
M0A,$;D(4!(Y"%02N0AP$CD,9!"Y#&`0.0Q8$SD('!.Y`!02N0`$$+4`NUX-(
M&P1L0XUV8TB$5H!(#03M100$Q$4!!"U``@1$1`P`C$0A]B%(`@!#1";VP4@"
M!$Q$++<@2`L$9D&&=B-(`@1+0"O78T@&!(9%@U9@2`($1D`F]D%(`P1C12OV
M84@"!(-$#`"+1`(`040MUR-(`@1,1(%6($@"!%M``02A11($2T(LM\!(`P1A
M1)MVPT@+`"M$&P2;10,`9D0"!%M``P1K1"3V@4@B]D%($00D0CNW0$@#!'%`
MD79#2"37PT@1!'%'AE;`2`,$<4`Q]F%(!`2&1";V@4@#!"1$&P`F1`,`8D0#
M!'M$%`2&0CNW($H#!')`*]=#2))V(TJ"5D!($@1R1P($8D4#!')`!`2"1`8`
M1D0C]F%(!`"11"'V(4@$!(9$,K=@2!,$84*&=F-(`0230"37(TH&!$9&D58@
M2@$$)D`F]B%(!`211#/V@4@!!$1$$@!31`$`(T0QUV-(`00R1(-68$@!!#1`
M`P0C1AP$DT,RM\!(!`2#1)1VPT@3`'-$%`141@0`AD0!!#1`!`231"+V04@A
M]B%(%02B0C2W($@"!)5`E78C2"37PT@5!)5&AE;`2`($54`U]D%(!`2&1";V
M@4@"!&1$%`!F1`(`040"!%1$&`0&0S2WH$H"!%Q`,]<C2)QVHTJ!5B!('`2<
M1@$$848"!%Q`!`2!1`8`)D0B]D%(!`"51"/V84@$!(9$/+=`2!D$(T.&=D-(
M`P290"37HTH&!(9'E5:@2@,$9D`F]F%(!`251#GV@4@#!"1$'``Y1`,`8D0U
MUT-(`P1\1()60$@#!'A``@2B1@<$^4`\M\!(!`2"1)AVPT@9`%E$&`281P0`
MAD0#!'A`!`291"'V(4CX`KZF(_9A2!8$P4(XMV!(`0260)9V8T@DU\-(%@06
M1X96P$@!!#9`(?8A2`0$AD0V]H%(&01$1!D`(T<8`%9$)K<@2!@$.$>9=B-(
M&`0'0P8$V40'!#9!.==C2(-68$@F]L%(`P0C1P8$!D,$!(-$./;!2`0`@40Y
MMP!+%@!V1"+V04@6!)9$A'8#2P4$HD`$!"1'!03%0B+V@4@DUR-(!02B0(%6
M($@B]J%(`02!1#:W0$@$"&%$F79#2`0(AD0D]H%(!@391B;VP4@$!(=`)]<#
M2P8$AD"85@!+(_9A2`<$^$0D]L%(%@@G1)AV@T@%",5&)?:A2!8$0T$CMX!(
M!02V0#;70T@#!'A$@E9`2"/V84@"!,)&%@CB1`4$HT`C]J%(%@C&1B'V(4CP
M`MZDF'9C2#;VP4H!!,%`)K=@2`$$-D`VUX-(!@381";VP4B$5H!(!@0F0"'V
MP4@$!,1&)_;A2!8(1$28=B-(%@C%1C;VP4H%!*=")[<@2`4$MD`'!/A$``,>
MIS;78T@(`[ZF)_;A2(-68$@%!*=`)_:A2`,$PT8B]D%(%@B#1!8(QD8"!`)#
M)K?@2)AVXT@V]L%*!@381";VP4@"!%9`-M<C2`($1D"!5B!()O9!2`$$P48D
M]H%(%@AA1)AVPT@6",5&-O;!2@4$I$(DM\!((`.^IB/V84@$!)A$./:!2`0$
MMD`EU^-(!`280(=6X$@0`QZG-O:!2`4$IT0'""5$!PCB1`($`T,G]N%(F';#
M2@($1T`CM\!*)]?#2`,$>$2&5L!((_9A2`8$YD0G]B%(`0BF1`($0T`!""1$
M(_9!2!@#GJ28=F-((?8A2`<$AT`DMV!(`03A0"?7PTH$!)A$EE;`2B3V@4@6
M!/9$)?:A2`$$)$`$"-9$!P2E0CCV(4@$"()$A78#2T`#OJ8BMP!+)/:!2`($
M140YUV-(!P3D0(168$@B]D%(&00D1R;VP4@'!.)`(_;A2`((V4:$=F-(`@A!
M1"+V04@H`SZD-O;!2@4$)D`AMV!(!02B0";7`TL!!"1$@E8`2R'V(4@&!,)$
M`@@F1P4$H4`A]J%(!PA'1"?VX4@P`UZD.?8A2P0$5D"6=B-(!`2'0"*W($@"
M!%9$(O9!2#;78T@$!()`@U9@2"+V@4@6!,-&.`-^I`<(UD28=D-(!PCE1"?V
MX4@%!'E`([=`2`4$IT`GUR-(`P1X1"/V84B!5B!(!02C0"/VH4@'!.%$(?;!
M2`8(QT:8=F-(!@C$1";VP4@$!*%"(;=@2`0$AD`!!#A$2`,>IR'V(4A0`[ZF
M)M=#2`0$@4""5D!((?:!2`8$PD0B]L%*%@CF1!8(Q48%!`)#F'8C2"*W($@V
M]L%*`@181"+V04@%!+9`-M=C2`4$HD"#5F!((O:A2!8$PT8C]N%(!PC61)AV
M0T@'".1$)_;A2`0$HT(CMT!(!`2'0"?7(T@#!'A$(_9A2%@#'J>!5B!(!`2#
M0`<$X41@`[ZF(_:!2```7J<A]L%(!@C'1@8(Q40%!`%#F'9C2`@`/J4AMV!(
M$`!>I2;VP4@!!#A$(?8A2`4$ID`FUT-(!02A0()60$@8`'ZE!@3"1"``GJ4A
M]J%(*`"^I2+VP4H6".9$F'8C2!8(Q$8$!*)"(`"PIB*W($@P`-ZE-O;!2@($
M6$0B]D%(!`260#;78T@$!()`@U9@2#@`_J4B]H%(%@3#1F@#?J08"-9$)_;A
M2!@(!4<X]@%+!01G0(-V0T@%!+A`)[=`2,`"'J<'!.-$(]<C2(%6($@G]N%(
M`P1A1`$(PT8%!*=`)_:A2`0()$0A]L%(!@1U0"3V@4@!!`%#F7;C2`$$)$`D
MUT-(@E9`2#BWX$@$!()$`PAD1!@$&4<#"&5$<`.^I`$$.$`$!(!`-O;!2B'V
M(4@"!+9`(_9A2`@$*$`VMR!(`@1#0"77XTB#5N!(@78C2`4$HT0!!,%&!02W
M0"/V`4D!!$%`(?8A2"7VH4@B]H%()O;!2```,+0(`'"T$`"PM!@`4+0@`-"T
M@`/>(P&`^FL``/XO`@"[)V`EO2/P_]XC6(%]IP``7K>``!\B`$!;:P(`NB==
M3%\DYW=_(']N0B`]##\D`@1"0$5GGR00`$"T'RXA(",W8D@R$%\D`2.$((FK
M8R!V5$(@1"6](R&7($@``("T"`!@M!@`0+0@`""T*`#@MS``X+=X`."S``!>
MIQ``WB,!@/IK``#^+Q\$_T<``/XO`@"[)]`DO2.#MD-*P/_>(P@`/K4)!/%'
M$`!>M3@`4"$8`'ZU"P3P1R``GK4,!/)'``!>MR@`OK4P`-ZU*``PI#``D*1X
M`+"@0@9!0B+V04@H`%"TH0-!0`0$@4`!!&1`,``PM'8`H/2A_8=!#03I1V(`
M(/0L$8A!+O:!28[6P$D!`*XA+=>@20T$+4$``/XO/P`I+#@`Z2PP`,DL*`"I
M+$$/*4@6\"!%60_I2($4P$8@`(DL/P#J+ID4P$88`&DL2`_)2!``22S'!NE(
MB!3`1E@/J4@'!.%$Q@;)2)@4P$8&!-E$"``I+%4/B4@0!.M'^0[J2)44P$;%
M!JE(5P[J2@4$J$1`#VE(%P3Y1L0&B4@```DM_`[*2`0$F$1G!^I(@!3`1ED/
M24@<!(='/P#J/ID4P$;#!FE(``#J+/@.JD@#!'5$9@?*2%</*4@8!`9'P@9)
M2)<4P$;F#HI(`@1`1&4'JD@X`(H_!@3%1,$&*4CE#FI(`00Y1&0'BD@P``H_
M!02D1,@&"4E``"DAY`Y*2`@$%T5C!VI(*`#*/`0$@T1B!TI(XPXJ2"``JCP#
M!&)$80<J2.(."DD8`(H\`@1!1&@'"DD0`&H\1P;J2`@`2CP'!.A$``#J/!""
M?:>$^5_3`@"Z)_`BO2.A!2U!J/\_Y"X![D,NU\!)#`".00B!?:<2!.Q'$03M
M1Q`$ZD<`0%MK`@"Z)W@`B['`(KTC``!>IP@`/J40`%ZE&`!^I2``GJ4H`+ZE
M,`#>I4``WB,!@/IK0`"_(0B!?:<M`:5!$`1%0:$)LD&-!#)$$@3M1P!`6VL"
M`+HG>``KH'`BO2,!`"U`>``KL*$5*$#H_S_D$`3K1RP!C4$)!"U!$()]IUCY
M7],"`+HG0"*](W/__\,``/XO`@"[)S`BO2/0_]XC@/]?(`@`/K4)!/%'$`!>
MM0H$\$<@`)ZU.`"1(0``7K<8`'ZU*`"^M2@`<:4P`+&E$03_1Y)V8$D2\$=&
M`02200$`$B(``$$X$C!`0J$=!T)X`"#T0``_('B`?:<R`3)`$`2000!`6VL"
M`+HGO"&](Q`$Z4<0@GVG,OE?TP(`NB>H(;TC-P!,+#@`*2Q"#DQ(-P!,/#``
M[#\H`.P_(`#L/Q@`[#\0`.P_008L2`@`[#\X`"D\PU"@21`$Z4<C%V%(P7"@
M2<(PH$D!!"-$(A="2&UQH$D!!")$PG!@20$$+40B%T1(PU!@20$$(D0C%V5(
MPC!@20$$(T0B%T9(*Q=G20$$(D0!!"M$<``IM!""?:<,^5_3`@"Z)Q`AO2,`
M`"FDJ(!]IQ`$Z4>!%B-(```J.```*:2!%B)(`0`J.```*:2!%B%(`@`J.```
M*:0#`"HX"``II($6(T@$`"HX"``II($6(D@%`"HX"``II($6(4@&`"HX"``I
MI`<`*C@0`"FD@18C2`@`*C@0`"FD@18B2`D`*C@0`"FD@18A2`H`*C@0`"FD
M"P`J.!@`*:2!%B-(#``J.!@`*:2!%B)(#0`J.!@`*:2!%B%(#@`J.!@`*:0/
M`"HX(``II($6(T@0`"HX(``II($6(D@1`"HX(``II($6(4@2`"HX(``II!,`
M*C@`0%MK`@"Z)P@`/J4``%ZG$`!>I1@`?J4@`)ZE*`"^I2`@O2,P`-XC`8#Z
M:Q\$_T<``/XO.``_('B`?:<R`3)`$`2000!`6VL"`+HGW!^](YC__\,"`+LG
MT!^](P``/23P_]XC(()AIF"`?:<``%ZW`$!;:P(`NB<``%ZGL!^](Q``WB,!
M@/IK``#^+Q\$_T<``/XO`@"[)Y`?O2,^%<)#``!>MP@`OK<``/XO``!>IP@`
MOJ<>%,)#`8#Z:R5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A
M<@!S:&]R="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E
M<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q
M+C`V,P!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&
M24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`]
M(#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:
M25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE
M+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S
M("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*
M;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O
M=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!
M3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'
M24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E
M860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]
M('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O
M9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,
M15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A
M8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2([
M"B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F
M:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F
M?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N
M92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@
M1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&
M2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U
M="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF
M("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@
M<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F
M:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C
M86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS
M965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@
M,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I
M>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L
M"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B10
M05)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M
M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68[
M"G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!
M0TA%`'!E<FQX<VDN8P````$;`SOH````'````&QX__^P!```#'O__P`!``!L
M?/__*`$``)Q]__]<`0``7'[__XP!``",@/__Q`$``'R#___\`0``K(3__S`"
M```\A?__4`(``(R%__]L`@``;(;__Y`"``",AO__I`(``&R)___D`@``S(G_
M_P0#```,B___-`,``"R1__]H`P``C)'__X0#```<DO__G`,``+R3___4`P``
M#)3___`#```<E?__'`0``!R>__]4!```#*'__X0$```LHO__W`0``*RY__\0
M!0``/+K__RP%``#<O/__9`4``#R___^<!0``$``````````!>E(`!'@/`1L-
M'@`0````&`````1Z__\\`````$4-#Q```````````7I2``1X&@$;#1X`,```
M`!@````\>___*`$```!##D!!B0="C`1"C0-%F@B*!HL%C@)G"L[-S,O*R=H.
M`$0+`"P```!,````.'S__[P`````0PZ@`42)$YH44PK)V@X`0@M$"LG:#@!$
M"TK)V@X``#0```!\````R'S__R0"````0P[``4&)%T6:&(H6BQ6,%$D*S,O*
MR=H.`$(+`F@*S,O*R=H.`$0+-````+0```#`?O__Y`(```!##E!$F@J)"8H(
M1HL'C`:-!8X$CP,"8@K/SLW,R\K)V@X`00L````P````[````'B!__\D`0``
M`$0.H"!!BX$$2(F#!(J"!)J$!%P*R\K)V@X`0PM<R\K)V@X`'````"`!``!T
M@O__C`````!$#A!#F@*)`5O)V@X````8````0`$``.2"__]0`````$0.$$*:
M`DW:#@``(````%P!```8@___V`````!$#J!`0YJ$"(F#"&[)V@X`````$```
M`(`!``#4@___$``````````\````E`$``."#___@`@```$0.X"%!BI@$1(N7
M!$B:F@2)F02,E@2-E02.E`2/DP1="L_.S<S+RLG:#@!""P``'````-0!``"`
MAO__5`````!##A!$F@*)`4W)V@X````L````]`$``,"&__\\`0```$0.H"!!
MBH($0YJ$!(F#!'@*RLG:#@!$"TK*R=H.```P````)`(``-"'__\8!@```$,.
M4$&)"4B*")H*BP>,!HT%C@0#:0$*SLW,R\K)V@X`0@L`&````%@"``"\C?__
M7`````!##B!$F@1/V@X``!0```!T`@```([__XP`````0PZ0`4::$C0```",
M`@``>([__Y0!````20[`@`1&BH9`BX5`C(1`0HV#0$.:B$")AT`"0PK-S,O*
MR=H.`$$+&````,0"``#@C___2`````!##A!"F@),V@X``"@```#@`@``%)#_
M_P0!````0PY008H&1(L%18D'F@B,!%`*S,O*R=H.`$,+-`````P#``#XD/__
M_`@```!$#N`"28TC69HHB2>*)HLEC"2.(H\A`L,*S\[-S,O*R=H.`$,+```L
M````1`,``,"9___L`@```$,.0$.)!T>*!IH(BP5"C`0">PK,R\K)V@X`0@L`
M```H````=`,``("<__\0`0```$,.,$&)!4::!HH$4@K*R=H.`$0+8LK)V@X`
M`"@```"@`P``M'/__Y`"````0PY03)H*B0F*"(L'`F8*R\K)V@X`00L`````
M,````,P#``!(G?__?!<```!!#H`'3)IPB6^*;HMMC&R-:XYJCVD#T07/SLW,
MR\K)V@X``!@`````!```E+3__X0`````0PX00IH"6]H.```T````'`0```BU
M__^<`@```$0.0$&)!T**!D*+!4*,!$2:"(T#C@("@`K.S<S+RLG:#@!!"P``
M`#0```!4!```<+?__V`"````0PXP0HD%0HH$0HP"1)H&BP.-`0*`"LW,R\K)
MV@X`0PL`````````&````(P$``"8N?__-`````!$#A!#F@)%V@X`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````8!T`(`$````0'0`@`0````$`````````T@(````````!
M`````````.("````````#`````````!(&``@`0````T`````````D&``(`$`
M```9`````````.#]`2`!````&P`````````(`````````!H`````````Z/T!
M(`$````<``````````@`````````]?[_;P````"0`@`@`0````4`````````
MJ`P`(`$````&`````````-@#`"`!````"@````````!7!`````````L`````
M````&``````````5`````````````````````P`````````0``(@`0````(`
M````````*`4````````4``````````<`````````%P`````````@$P`@`0``
M``<`````````,!(`(`$````(`````````/``````````"0`````````8````
M`````````'```````0`````````>``````````@`````````^___;P`````!
M`````````/[__V\`````P!$`(`$```#___]O``````$`````````\/__;P``
M````$0`@`0``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````I005(N<&T*````````````````````````````
M````I!@`(`$```"H&``@`0```*P8`"`!````L!@`(`$```"T&``@`0```+@8
M`"`!````O!@`(`$```#`&``@`0````````````````````````#$&``@`0``
M`,@8`"`!````S!@`(`$```#0&``@`0```-08`"`!````V!@`(`$```#<&``@
M`0```.`8`"`!````Y!@`(`$``````````````.@8`"`!````[!@`(`$```#P
M&``@`0``````````````]!@`(`$```#X&``@`0```/P8`"`!````````````
M`````````````````````````!D`(`$````$&0`@`0``````````````"!D`
M(`$````,&0`@`0```!`9`"`!````%!D`(`$````8&0`@`0```!P9`"`!````
M(!D`(`$``````````````"09`"`!````*!D`(`$````L&0`@`0```#`9`"`!
M````-!D`(`$````X&0`@`0```#P9`"`!````0!D`(`$```!$&0`@`0```$@9
M`"`!````3!D`(`$```!0&0`@`0```%09`"`!````6!D`(`$```!<&0`@`0``
M````````````8!D`(`$```!D&0`@`0```&@9`"`!````;!D`(`$```!P&0`@
M`0```'09`"`!````>!D`(`$```!\&0`@`0```(`9`"`!````0$,`(`$````!
M``(`````````````````D6,`(`$```!'0T,Z("A$96)I86X@,3,N,BXP+3$S
M*2`Q,RXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N
M9V]T`"YS9&%T80`N<V)S<P`N8V]M;65N=```````````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````X`@`@`0```#@"````````$P``````
M``````````````$````````````````````3````!P````(`````````3`(`
M(`$```!,`@```````"0````````````````````$````````````````````
M)@````<````"`````````'`"`"`!````<`(````````@````````````````
M````!````````````````````#0```#V__]O`@````````"0`@`@`0```)`"
M````````2`$````````%``````````@````````````````````^````"P``
M``(`````````V`,`(`$```#8`P```````-`(````````!@````$````(````
M`````!@`````````1@````,````"`````````*@,`"`!````J`P```````!7
M!````````````````````0```````````````````$X```#___]O`@``````
M````$0`@`0`````1````````O``````````%``````````(``````````@``
M``````!;````_O__;P(`````````P!$`(`$```#`$0```````'``````````
M!@````$````(````````````````````:@````0````"`````````#`2`"`!
M````,!(```````#P``````````4`````````"``````````8`````````'0`
M```$````0@`````````@$P`@`0```"`3````````*`4````````%````#```
M``@`````````&`````````!^`````0````8`````````2!@`(`$```!(&```
M`````#@````````````````````(````````````````````>0````$````&
M`````````(`8`"`!````@!@``````````0``````````````````$```````
M`````````````(0````!````!@````````"`&0`@`0```(`9````````$$<`
M`````````````````!````````````````````"*`````0````8`````````
MD&``(`$```"08````````"@````````````````````(````````````````
M````D`````$````"`````````+A@`"`!````N&````````!:0```````````
M`````````0```````````````````)@````!`````@`````````4H0`@`0``
M`!2A````````[`````````````````````0```````````````````"F````
M`0````(``````````*(`(`$`````H@```````-`$```````````````````(
M````````````````````L`````X````#`````````.#]`2`!````X/T`````
M```(````````````````````"``````````(`````````+P````/`````P``
M``````#H_0$@`0```.C]````````"`````````````````````@`````````
M"`````````#(````!@````,`````````\/T!(`$```#P_0```````!`"````
M````!@`````````(`````````!``````````T0````$````#````````````
M`B`!```````!```````)`````````````````````0``````````````````
M`-<````!`````P`````````0``(@`0```!```0``````*`(`````````````
M``````@```````````````````#<`````0````,``!``````.`("(`$````X
M`@$``````!@````````````````````(````````````````````XP````@`
M```#```0`````%`"`B`!````4`(!```````H````````````````````"```
M`````````````````.D````!````,````````````````````%`"`0``````
M'P````````````````````$``````````0`````````!`````P``````````
M``````````````!O`@$``````/(````````````````````!````````````
&````````
